@@ -11,6 +11,7 @@ get.formula <- function(formula) {
   # for numeric values, get the formulas from those rownumbers of thermo$obigt
   i <- suppressWarnings(as.numeric(formula))
   # we can't have more than the number of rows in thermo$obigt
+  thermo <- get("thermo")
   iover <- i > nrow(thermo$obigt)
   iover[is.na(iover)] <- FALSE
   if(any(iover)) stop(paste("species number(s)",paste(i[iover],collapse=" "),
@@ -36,7 +37,7 @@ i2A <- function(formula) {
     A <- t(sapply(msz, c))
     # add names from character argument
     # or from thermo$obigt for numeric argument
-    if(is.numeric(formula[1])) rownames(A) <- thermo$obigt$name[formula]
+    if(is.numeric(formula[1])) rownames(A) <- get("thermo")$obigt$name[formula]
     else rownames(A) <- formula
   }
   return(A)
@@ -78,6 +79,7 @@ as.chemical.formula <- function(makeup, drop.zero=TRUE) {
 
 mass <- function(formula) {
   # calculate the mass of elements in chemical formulas
+  thermo <- get("thermo")
   formula <- i2A(get.formula(formula))
   ielem <- match(colnames(formula), thermo$element$element)
   if(any(is.na(ielem))) stop(paste("element(s)",
@@ -88,6 +90,7 @@ mass <- function(formula) {
 
 entropy <- function(formula) {
   # calculate the standard molal entropy at Tref of elements in chemical formulas
+  thermo <- get("thermo")
   formula <- i2A(get.formula(formula))
   ielem <- match(colnames(formula), thermo$element$element)
   if(any(is.na(ielem))) warning(paste("element(s)",
@@ -96,7 +99,7 @@ entropy <- function(formula) {
   return(entropy)
 }
 
-GHS <- function(formula, G=NA, H=NA, S=NA, T=thermo$opt$Tr) {
+GHS <- function(formula, G=NA, H=NA, S=NA, T=get("thermo")$opt$Tr) {
   # for all NA in G, H and S, do nothing
   # for no  NA in G, H and S, do nothing
   # for one NA in G, H and S, calculate its value from the other two:
